VaR_erlang.RdValue-at-Risk of the Erlang distribution with shape parameter \(n\) and rate parameter \(\beta\).
VaR_erlang(kap, shape, rate = 1/scale, scale = 1/rate)
| kap | probability. |
|---|---|
| shape | shape parameter \(n\), must be positive integer. |
| rate | \(\beta\) is the rate parameter, must be positive. |
| scale | alternative parameterization to rate parameter, scale = 1 / rate. |
Function :
MGF_erlang gives the moment generating function (MGF).
derlang gives the density function.
perlang gives the cumulative density function.
E_erlang gives the expected value.
V_erlang gives the variance.
kthmoment_erlang gives the kth moment.
Etrunc_erlang gives the truncated mean.
SL_erlang gives the stop-loss.
Elim_erlang gives the limited mean.
Mexcess_erlang gives the mean excess loss.
TVaR_erlang gives the Tail Value-at-Risk.
VaR_erlang gives the Value-at-Risk.
Invalid parameter values will return an error detailing which parameter is problematic.
The Erlang distribution with shape parameter \(n\) and rate parameter \(\beta\) has density: $$f\left(x\right) = \frac{\beta^{n}}{\Gamma(n)} x^{n - 1}% \mathrm{e}^{-\beta x}$$ for \(x \in \mathcal{R}^+\), \(\beta > 0\), \(n \in \mathcal{N}^+\)
Wrapper of qgamma from package stats.
Other Erlang Distribution:
E_erlang(),
Elim_erlang(),
Etrunc_erlang(),
MGF_erlang(),
Mexcess_erlang(),
SL_erlang(),
TVaR_erlang(),
V_erlang(),
derlang(),
kthmoment_erlang(),
perlang()
# With scale parameter VaR_erlang(kap = .2, shape = 3, scale = 4)#> [1] 6.140177# With rate parameter VaR_erlang(kap = .2, shape = 3, rate = 0.25)#> [1] 6.140177